==> haskell-tidal-1.7.4-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tidal.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tidal
version:              1.7.4
visibility:           public
id:                   tidal-1.7.4-1HvBr8w3q0G8uY8NMcT0Wj
key:                  tidal-1.7.4-1HvBr8w3q0G8uY8NMcT0Wj
license:              GPL-3.0-only
copyright:            (c) Alex McLean and other contributors, 2020
maintainer:
    Alex McLean <alex@slab.org>, Mike Hodnick <mike.hodnick@gmail.com>

author:               Alex McLean
stability:            Experimental
homepage:             http://tidalcycles.org/
synopsis:             Pattern language for improvised music
description:
    Tidal is a domain specific language for live coding patterns.

category:             Sound
abi:                  9def5fc64ef0cfb07d7a26d49220f351
exposed:              True
exposed-modules:
    Paths_tidal Sound.Tidal.Bjorklund Sound.Tidal.Carabiner
    Sound.Tidal.Chords Sound.Tidal.Config Sound.Tidal.Context
    Sound.Tidal.Control Sound.Tidal.Core Sound.Tidal.EspGrid
    Sound.Tidal.Params Sound.Tidal.ParseBP Sound.Tidal.Pattern
    Sound.Tidal.Scales Sound.Tidal.Show Sound.Tidal.Simple
    Sound.Tidal.Stream Sound.Tidal.Tempo Sound.Tidal.Time
    Sound.Tidal.Transition Sound.Tidal.UI Sound.Tidal.Utils
    Sound.Tidal.Version

import-dirs:          /usr/lib/ghc-8.10.4/site-local/tidal-1.7.4
library-dirs:         /usr/lib/ghc-8.10.4/site-local/tidal-1.7.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/tidal-1.7.4
hs-libraries:         HStidal-1.7.4-1HvBr8w3q0G8uY8NMcT0Wj
depends:
    base-4.14.1.0 bifunctors-5.5.11-icaD4DhYlIBnqPEujMowA
    bytestring-0.10.12.0 clock-0.8.2-9UFKXEvaIlvHBGUfGAYdEd
    colour-2.3.5-4H3TZkupTLU8mrcf8Q628B containers-0.6.2.1
    deepseq-1.4.4.0 hosc-0.18-6xyyeriy2zcFGg2DXK7Dpz
    network-3.1.2.1-IbGp7WYUsXwHVhR4UsCZRD parsec-3.1.14.0
    primitive-0.7.1.0-8SQOE2avl1z6s0yo5beOHC
    random-1.2.0-K0s4YXXokSTCl8DDdtVkkS text-1.2.4.1
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-tidal/html/tidal.haddock
haddock-html:         /usr/share/doc/haskell-tidal/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tidal-1.7.4-3-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tidal.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tidal
version:              1.7.4
visibility:           public
id:                   tidal-1.7.4-E6tG3O719JxCnKErDLBdf3
key:                  tidal-1.7.4-E6tG3O719JxCnKErDLBdf3
license:              GPL-3.0-only
copyright:            (c) Alex McLean and other contributors, 2020
maintainer:
    Alex McLean <alex@slab.org>, Mike Hodnick <mike.hodnick@gmail.com>

author:               Alex McLean
stability:            Experimental
homepage:             http://tidalcycles.org/
synopsis:             Pattern language for improvised music
description:
    Tidal is a domain specific language for live coding patterns.

category:             Sound
abi:                  acbffc82f7bea296516746638d965e54
exposed:              True
exposed-modules:
    Paths_tidal Sound.Tidal.Bjorklund Sound.Tidal.Carabiner
    Sound.Tidal.Chords Sound.Tidal.Config Sound.Tidal.Context
    Sound.Tidal.Control Sound.Tidal.Core Sound.Tidal.EspGrid
    Sound.Tidal.Params Sound.Tidal.ParseBP Sound.Tidal.Pattern
    Sound.Tidal.Scales Sound.Tidal.Show Sound.Tidal.Simple
    Sound.Tidal.Stream Sound.Tidal.Tempo Sound.Tidal.Time
    Sound.Tidal.Transition Sound.Tidal.UI Sound.Tidal.Utils
    Sound.Tidal.Version

import-dirs:          /usr/lib/ghc-8.10.4/site-local/tidal-1.7.4
library-dirs:         /usr/lib/ghc-8.10.4/site-local/tidal-1.7.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/tidal-1.7.4
hs-libraries:         HStidal-1.7.4-E6tG3O719JxCnKErDLBdf3
depends:
    base-4.14.1.0 bifunctors-5.5.11-KymOnNAZFtQDRJwOea8vch
    bytestring-0.10.12.0 clock-0.8.2-9UFKXEvaIlvHBGUfGAYdEd
    colour-2.3.5-HHkRLY4S6LD9Rlcn6haToE containers-0.6.2.1
    deepseq-1.4.4.0 hosc-0.18-4ys4VVGWX4tKOEhnPgWlS7
    network-3.1.2.1-3J2farqahIBByMpQGhmaOp parsec-3.1.14.0
    primitive-0.7.1.0-B2oAiHIszjW9d5BDCCv0d7
    random-1.2.0-EwsL2pbBqkD1oyGGKHDL6O text-1.2.4.1
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-tidal/html/tidal.haddock
haddock-html:         /usr/share/doc/haskell-tidal/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
